peruseR is a collection of document templates and data that we hope
will be useful for future planners of useR! conferences. It includes LaTeX
document templates as well as examples of previous year proposals that may
be used to generate a new proposal.
At the moment, not too much.
1 | peruseR()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.